import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Controller, Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import { level } from './logger/level.enum';
import loggerOptions from './logger/logger';

@Controller()
export class UserController {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    exchange: 'logging',
    routingKey: 'user.create.info',
    queue: 'logging-user-create-info',
  })
  public async userCreatedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('user', level.info, 'info'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    exchange: 'logging',
    routingKey: 'user.create.warning',
    queue: 'logging-user-create-warning',
  })
  public async userCreatedWarningHandler(message: string) {
    this.logger.configure(loggerOptions('user', level.warning, 'warning'));
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    exchange: 'logging',
    routingKey: 'user.create.crit',
    queue: 'logging-user-create-crit',
  })
  public async userCreatedCriticalHandler(message: string) {
    this.logger.configure(loggerOptions('user', level.crit, 'critical'));
    this.logger.crit(JSON.parse(message));
  }
}
